# User API E-Mail Confirm

This module adds a REST resource to update a user's email address via a
confirmation email.

Optional integration with the `simple_oauth_magic_link` module is also provided.

## Change of core behavior

WARNING: When email verification is enabled in account settings, it changes the
core behavior of how a user can change the email address.

The user is not able to directly change the email address on the user entity.
However, other users (e.g. an admin) is able to change the email address.

## Installation

- Enable the module
- Enable the `Update user email with confirmation resource` REST resource.
- Set the `restful post user_api_email_confirm_update_mail` permission for
  logged in users.

## E-Mail templates

E-Mail templates can be configured in '/admin/config/people/accounts'.

When the `simple_oauth_magic_link` module is installed and enabled, the
`[user:magic-link-email-verification]` token can be used in the email templates.

This token generates a magic link with the needed email change hash and
timestamp parameters.

## E-Mail change workflow

1. `POST` request to `/user-api/update-email` with the following payload:

```json
{
  "mail": "new-user-email@example.com"
}
```

This triggers two emails to be sent to the user:

- A notification email to the current email address of the user to notify about
  the pending email change.
- A verfification email to the new email address to verify the user's ownership
  of the new email address.

**This does not change the email on the user entity!**

2. User gets a login link alongside a timestamp and hash query parameter via
   email

It is up to the client implementation to log the user in via the login link and
extract the hash and timestamp from the url.

3. `POST` request to `/user-api/confirm-email` with the following payload:

```json
{
  "mail": "new-user-email@example.com",
  "hash": "the-hash-from-the-login-link",
  "timestamp": "timestamp-from-the-login-link"
}
```

When the verification is successful, the user's email address is then changed to
the new value.

## Technical details

Directly changing the email address by the user itself is prohibited via a
presave hook if verification is enabled.

When changing the email via the REST resource, a hash similar to a password
change is generated by the `user_pass_rehash` function, but with the new email
address the user should be updated to.

By requesting the REST resource again with the new email, the hash and the hash
timestamp, the server is able to verify the hash and detect if the new email
address or the user was tampered with.

## Acknowledgements

The majority of the implementation comes from this drupal core merge request:
[https://git.drupalcode.org/project/drupal/-/merge_requests/437/diffs](https://git.drupalcode.org/project/drupal/-/merge_requests/437/diffs)
Drupal issue:
[https://www.drupal.org/project/drupal/issues/85494](https://www.drupal.org/project/drupal/issues/85494)
